package com.yijia.station.controller;

import java.util.Arrays;
import java.util.List;

import com.yijia.common.core.domain.model.LoginUser;
import com.yijia.common.utils.SecurityUtils;
import com.yijia.system.service.ISysUserService;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;
import com.yijia.common.annotation.Log;
import com.yijia.common.core.controller.BaseController;
import com.yijia.common.core.domain.AjaxResult;
import com.yijia.common.enums.BusinessType;
import com.yijia.station.domain.PayOrder;
import com.yijia.station.service.IPayOrderService;
import com.yijia.common.utils.poi.ExcelUtil;
import com.yijia.common.core.page.TableDataInfo;

/**
 * 订单支付Controller
 *
 * @author yijia
 * @date 2020-12-10
 */
@RestController
@RequestMapping("/station/order")
public class PayOrderController extends BaseController
{
    @Autowired
    private IPayOrderService payOrderService;
    @Autowired
    private ISysUserService sysUserService;
    /**
     * 查询订单支付列表
     */
    @PreAuthorize("@ss.hasPermi('station:order:list')")
    @GetMapping("/list")
    public TableDataInfo list(PayOrder payOrder)
    {
        LoginUser currentUser = SecurityUtils.getLoginUser();
        String selectDeptid= sysUserService.getUserRoleDeptId(currentUser);
        if(selectDeptid !=null && selectDeptid!=""){
            List<String> list = Arrays.asList(selectDeptid.split(","));
            payOrder.setStationIdList(list);
        }
        startPage();
        payOrder.setStatus("1");
        List<PayOrder> list = payOrderService.selectPayOrderList(payOrder);
        return getDataTable(list);
    }
    /**
     * 查询订单支付列表
     */
    @PreAuthorize("@ss.hasPermi('station:order:listInfo')")
    @GetMapping("/listInfo")
    public TableDataInfo listInfo(PayOrder payOrder)
    {
        LoginUser currentUser = SecurityUtils.getLoginUser();
        String selectDeptid= sysUserService.getUserRoleDeptId(currentUser);
        if(selectDeptid !=null && selectDeptid!=""){
            List<String> list = Arrays.asList(selectDeptid.split(","));
            payOrder.setStationIdList(list);
        }
        payOrder.setOrderType("1");
        List<PayOrder> list = payOrderService.selectPayOrderList(payOrder);
        return getTable(list);
    }

    /**
     * 查询总金额，总升数
     * @param payOrder
     * @return
     */
    @PreAuthorize("@ss.hasPermi('station:order:selectDaySources')")
    @GetMapping("/selectDaySources")
    public AjaxResult selectDaySources(PayOrder payOrder)
    {
        LoginUser currentUser = SecurityUtils.getLoginUser();
        String selectDeptid= sysUserService.getUserRoleDeptId(currentUser);
        if(selectDeptid !=null && selectDeptid!=""){
            List<String> list = Arrays.asList(selectDeptid.split(","));
            payOrder.setStationIdList(list);
        }
        payOrder.setStatus("1");
        payOrder.setOrderType("1");
        PayOrder order = payOrderService.selectDaySources(payOrder);
        return AjaxResult.success(order);
    }

    /***
     * 根据油品分类，查询油品的总金额，总升数
     * @param payOrder
     * @return
     */
    @PreAuthorize("@ss.hasPermi('station:order:selectOilTypeSources')")
    @GetMapping("/selectOilTypeSources")
    public TableDataInfo selectOilTypeSources(PayOrder payOrder)
    {
        LoginUser currentUser = SecurityUtils.getLoginUser();
        String selectDeptid= sysUserService.getUserRoleDeptId(currentUser);
        if(selectDeptid !=null && selectDeptid!=""){
            List<String> list = Arrays.asList(selectDeptid.split(","));
            payOrder.setStationIdList(list);
        }
        payOrder.setStatus("1");
        payOrder.setOrderType("1");
        List<PayOrder> orderList = payOrderService.selectOilTypeSources(payOrder);
        return getTable(orderList);
    }

    /***
     * 根据油品分类，查询油品的总金额，总升数
     * @param payOrder
     * @return
     */
    @PreAuthorize("@ss.hasPermi('station:order:selectOverViewData')")
    @GetMapping("/selectOverViewData")
    public AjaxResult selectOverViewData(PayOrder payOrder)
    {
        LoginUser currentUser = SecurityUtils.getLoginUser();
        String selectDeptid= sysUserService.getUserRoleDeptId(currentUser);
        if(selectDeptid !=null && selectDeptid!=""){
            List<String> list = Arrays.asList(selectDeptid.split(","));
            payOrder.setStationIdList(list);
        }
        payOrder.setStatus("1");
        payOrder.setOrderType("1");
        PayOrder order = payOrderService.selectOverViewData(payOrder);
        return AjaxResult.success(order);
    }

    /**
     * 日报数据详细
     */
    @PreAuthorize("@ss.hasPermi('station:order:selectDayReportDetail')")
    @GetMapping("/selectDayReportDetail")
    public TableDataInfo selectDayReportDetail(PayOrder payOrder)
    {
        LoginUser currentUser = SecurityUtils.getLoginUser();
        String selectDeptid= sysUserService.getUserRoleDeptId(currentUser);
        if(selectDeptid !=null && selectDeptid!=""){
            List<String> list = Arrays.asList(selectDeptid.split(","));
            payOrder.setStationIdList(list);
        }
        //默认当前登陆人的ID 5冯总油站
        startPage();
        payOrder.setStatus("1");
        payOrder.setOrderType("1");
        List<PayOrder>  orderList = payOrderService.selectDayReport(payOrder);
        return getDataTable(orderList);
    }

    /***
     * 根据油品分类，查询油品的总金额，总升数
     * @param payOrder
     * @return
     */
    @PreAuthorize("@ss.hasPermi('station:order:selectDayReport')")
    @GetMapping("/selectDayReport")
    public TableDataInfo selectDayReport(PayOrder payOrder)
    {
        LoginUser currentUser = SecurityUtils.getLoginUser();
        String selectDeptid= sysUserService.getUserRoleDeptId(currentUser);
        if(selectDeptid !=null && selectDeptid!=""){
            List<String> list = Arrays.asList(selectDeptid.split(","));
            payOrder.setStationIdList(list);
        }
        payOrder.setStatus("1");
        payOrder.setOrderType("1");
       List<PayOrder>  orderList = payOrderService.selectDayReport(payOrder);
        return getTable(orderList);
    }

    /**
     * 导出订单支付列表
     */
    @PreAuthorize("@ss.hasPermi('station:order:export')")
    @Log(title = "订单支付", businessType = BusinessType.EXPORT)
    @GetMapping("/export")
    public AjaxResult export(PayOrder payOrder)
    {
        LoginUser currentUser = SecurityUtils.getLoginUser();
        String selectDeptid= sysUserService.getUserRoleDeptId(currentUser);
        if(selectDeptid !=null && selectDeptid!=""){
            List<String> list = Arrays.asList(selectDeptid.split(","));
            payOrder.setStationIdList(list);
        }
        payOrder.setStatus("1");
        payOrder.setOrderType("1");
        List<PayOrder> list = payOrderService.selectPayOrderExport(payOrder);
        ExcelUtil<PayOrder> util = new ExcelUtil<PayOrder>(PayOrder.class);

        return util.exportExcel(list, "order");
    }


    /**
     * 获取订单支付详细信息
     */
    @PreAuthorize("@ss.hasPermi('station:order:query')")
    @GetMapping(value = "/{orderId}")
    public AjaxResult getInfo(@PathVariable("orderId") Long orderId)
    {
        return AjaxResult.success(payOrderService.selectPayOrderById(orderId));
    }

    /**
     * 获取92号汽油数据
     * @param payOrder
     * @return
     */
    @PreAuthorize("@ss.hasPermi('station:order:listQydata92')")
    @GetMapping("/listQydata92")
    public TableDataInfo listQydata92(PayOrder payOrder)
    {
        LoginUser currentUser = SecurityUtils.getLoginUser();
        String selectDeptid= sysUserService.getUserRoleDeptId(currentUser);
        if(selectDeptid !=null && selectDeptid!=""){
            List<String> list = Arrays.asList(selectDeptid.split(","));
            payOrder.setStationIdList(list);
        }
        payOrder.setOilName("92#");
        payOrder.setStatus("1");
        payOrder.setOrderType("1");
        List<PayOrder>  orderList = payOrderService.listQydata(payOrder);
        return getTable(orderList);
    }
    /**
     * 获取95号汽油数据
     * @param payOrder
     * @return
     */
    @PreAuthorize("@ss.hasPermi('station:order:listQydata95')")
    @GetMapping("/listQydata95")
    public TableDataInfo listQydata95(PayOrder payOrder)
    {
        LoginUser currentUser = SecurityUtils.getLoginUser();
        String selectDeptid= sysUserService.getUserRoleDeptId(currentUser);
        if(selectDeptid !=null && selectDeptid!=""){
            List<String> list = Arrays.asList(selectDeptid.split(","));
            payOrder.setStationIdList(list);
        }
        payOrder.setOilName("95#");
        payOrder.setStatus("1");
        payOrder.setOrderType("1");
        List<PayOrder>  orderList = payOrderService.listQydata(payOrder);
        return getTable(orderList);
    }
    /**
     * 获取97号汽油数据
     * @param payOrder
     * @return
     */
    @PreAuthorize("@ss.hasPermi('station:order:listQydata97')")
    @GetMapping("/listQydata97")
    public TableDataInfo listQydata97(PayOrder payOrder)
    {
        LoginUser currentUser = SecurityUtils.getLoginUser();
        String selectDeptid= sysUserService.getUserRoleDeptId(currentUser);
        if(selectDeptid !=null && selectDeptid!=""){
            List<String> list = Arrays.asList(selectDeptid.split(","));
            payOrder.setStationIdList(list);
        }
        payOrder.setOilName("97#");
        payOrder.setStatus("1");
        payOrder.setOrderType("1");
        List<PayOrder>  orderList = payOrderService.listQydata(payOrder);
        return getTable(orderList);
    }

    /**
     * 获取97号汽油数据
     * @param payOrder
     * @return
     */
    @PreAuthorize("@ss.hasPermi('station:order:listQydata20')")
    @GetMapping("/listQydata20")
    public TableDataInfo listQydata20(PayOrder payOrder)
    {
        LoginUser currentUser = SecurityUtils.getLoginUser();
        String selectDeptid= sysUserService.getUserRoleDeptId(currentUser);
        if(selectDeptid !=null && selectDeptid!=""){
            List<String> list = Arrays.asList(selectDeptid.split(","));
            payOrder.setStationIdList(list);
        }
        payOrder.setOilName("-20#");
        payOrder.setStatus("1");
        payOrder.setOrderType("1");
        List<PayOrder>  orderList = payOrderService.listQydata(payOrder);
        return getTable(orderList);
    }
    /**
     * 获取97号汽油数据
     * @param payOrder
     * @return
     */
    @PreAuthorize("@ss.hasPermi('station:order:listQydata0')")
    @GetMapping("/listQydata0")
    public TableDataInfo listQydata0(PayOrder payOrder)
    {
        LoginUser currentUser = SecurityUtils.getLoginUser();
        String selectDeptid= sysUserService.getUserRoleDeptId(currentUser);
        if(selectDeptid !=null && selectDeptid!=""){
            List<String> list = Arrays.asList(selectDeptid.split(","));
            payOrder.setStationIdList(list);
        }
        payOrder.setOilName("0#");
        payOrder.setStatus("1");
        payOrder.setOrderType("1");
        List<PayOrder>  orderList = payOrderService.listQydata(payOrder);
        return getTable(orderList);
    }
    /**
     * 获取97号汽油数据
     * @param payOrder
     * @return
     */
    @PreAuthorize("@ss.hasPermi('station:order:listQydata10')")
    @GetMapping("/listQydata10")
    public TableDataInfo listQydata10(PayOrder payOrder)
    {
        LoginUser currentUser = SecurityUtils.getLoginUser();
        String selectDeptid= sysUserService.getUserRoleDeptId(currentUser);
        if(selectDeptid !=null && selectDeptid!=""){
            List<String> list = Arrays.asList(selectDeptid.split(","));
            payOrder.setStationIdList(list);
        }
        payOrder.setOilName("-10#");
        payOrder.setStatus("1");
        payOrder.setOrderType("1");
        List<PayOrder>  orderList = payOrderService.listQydata(payOrder);
        return getTable(orderList);
    }
    /**
     * 获取x轴数据
     * @param payOrder
     * @return
     */
    @PreAuthorize("@ss.hasPermi('station:order:listXdata')")
    @GetMapping("/listXdata")
    public TableDataInfo listXdata(PayOrder payOrder)
    {
        LoginUser currentUser = SecurityUtils.getLoginUser();
        String selectDeptid= sysUserService.getUserRoleDeptId(currentUser);
        if(selectDeptid !=null && selectDeptid!=""){
            List<String> list = Arrays.asList(selectDeptid.split(","));
            payOrder.setStationIdList(list);
        }
        payOrder.setStatus("1");
        payOrder.setOrderType("1");
        List<PayOrder>  orderList = payOrderService.listXdata(payOrder);
        return getTable(orderList);
    }
    /**
     * 查询油站第一笔订单的数据
     */
    @PreAuthorize("@ss.hasPermi('station:order:getPayOrderInfoMin')")
    @GetMapping("/getPayOrderInfoMin")
    public AjaxResult getPayOrderInfoMin(PayOrder payOrder)
    {
        LoginUser currentUser = SecurityUtils.getLoginUser();
        payOrder.setStationId(currentUser.getUser().getDeptId());
        payOrder.setStatus("1");
        payOrder.setOrderType("1");
        return  AjaxResult.success(payOrderService.getPayOrderInfoMin(payOrder));
    }
    /**
     * 新增订单支付
     */
    @PreAuthorize("@ss.hasPermi('station:order:add')")
    @Log(title = "订单支付", businessType = BusinessType.INSERT)
    @PostMapping
    public AjaxResult add(@RequestBody PayOrder payOrder)
    {
        return toAjax(payOrderService.insertPayOrder(payOrder));
    }

    /**
     * 修改订单支付
     */
    @PreAuthorize("@ss.hasPermi('station:order:edit')")
    @Log(title = "订单支付", businessType = BusinessType.UPDATE)
    @PutMapping
    public AjaxResult edit(@RequestBody PayOrder payOrder)
    {
        return toAjax(payOrderService.updatePayOrder(payOrder));
    }

    /**
     * 删除订单支付
     */
    @PreAuthorize("@ss.hasPermi('station:order:remove')")
    @Log(title = "订单支付", businessType = BusinessType.DELETE)
	@DeleteMapping("/{orderIds}")
    public AjaxResult remove(@PathVariable Long[] orderIds)
    {
        return toAjax(payOrderService.deletePayOrderByIds(orderIds));
    }
}
